@@ -38,10 +38,12 @@
 #include <QImageReader>
 #include <QDir>
 #include <KLocalizedString>
+#include <KCrash>
 
 int main(int argc, char *argv [])
 {
   QApplication app(argc, argv);
+  QImageReader::setAllocationLimit(0); // no explicit memory limit
 
   KLocalizedString::setApplicationDomain("kolourpaint");
 
@@ -86,6 +88,7 @@ int main(int argc, char *argv [])
 
   QCommandLineParser cmdLine;
   KAboutData::setApplicationData(aboutData);
+  KCrash::initialize();
   QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kolourpaint"), QApplication::windowIcon()));
   cmdLine.addPositionalArgument(QStringLiteral("files"), i18n("Image files to open, optionally"), QStringLiteral("[files...]"));
 
